1.1.1 2021-03-27
----------------

* Fixes for the changes in uncompyle6 and xdis.
* Require a more recent xdis and uncompyle6.

1.1.0 2018-03-18
----------------

See ChangeLog

1.0.0 2018-02-17
-----------------

First release to get this out there.

It works fine, but could use improvement writing
test cases. Backporting to 2.7 is left as an excercise to the reader.
